@@ -19,14 +19,18 @@ def main_addition():
 
     Read arguments from `sys.argv[1:]`.
 
-    .. Note:: Will be used as `pyyc_addition` entry-point in
-              :ref:`setup.cfg`.
+    .. Note:: Will be used as `pyyc_addition` entry-point in :ref:`setup.cfg`.
     """
 
     try:
         iargs = [ int(arg) for arg in sys.argv[1:] ]
     except ValueError:
-        print("Only integers accepted as command-line arguments:", sys.argv[1:])
+        print("Only integers accepted as command-line arguments, got", sys.argv[1:])
+        return
+    else:
+        if len(iargs) < 2:
+            print("At least two arguments on command line, got", len(sys.argv[1:]))
+            return
 
     print(" + ".join([ str(arg) for arg in iargs ]), "=", sum(iargs))
 
