@@ -13,21 +13,36 @@ import os, sys
 
 
 def addition(*args):
-    """
+    r"""
     Addition function (undefined type).
 
-    .. Note:: just a wrapper to :py:func:`sum`.
+    Arguments should support mutual addition:
+
+    .. math::
+
+       \mathrm{out} = \sum_i \mathrm{arg}_i
 
     :param args: parameters
     :return: python addition of args
+    :raises TypeError: arguments cannot be summed together
 
     >>> addition(1, 2, 3)
     6
-    >>> addition("titi", "toto")
-    'tititoto'
+    >>> addition("abc", "def")
+    'abcdef'
+    >>> addition([1], [2, 3], [4, 5, 6])
+    [1, 2, 3, 4, 5, 6]
+    >>> addition(1, "abc")
+    Traceback (most recent call last):
+        ...
+    TypeError: unsupported operand type(s) for +=: 'int' and 'str'
     """
 
-    return sum(args)
+    out = args[0]
+    for arg in args[1:]:
+        out += arg
+
+    return out
 
 
 def addition_int(*args):
@@ -41,7 +56,9 @@ def addition_int(*args):
 
     >>> addition_int(1, 2, 3)
     6
-    >>> addition_int("titi", "toto")
+    >>> addition_int('1', 2)
+    3
+    >>> addition_int("abc", "def")
     Traceback (most recent call last):
         ...
     ValueError: Arguments must cast to integer.
@@ -55,32 +72,37 @@ def addition_int(*args):
     return sum(iargs)
 
 
-_python_version = float(f"{sys.version_info.major}.{sys.version_info.minor:02d}")
-if _python_version >= 3.10:
+if sys.version_info[:2] >= (3, 10):
     from importlib.resources import files  # Python 3.10+
 else:
     from importlib_resources import files  # External
 
-pyyc_path = files("pyyc.config")  #: Path to pyyc configuration file.
+PYYC_PATH = files("pyyc.config")           #: Path to pyyc configuration file.
+
 
 def read_config(cfgname="default.cfg"):
     """
     Get config from configuration file.
 
     If the input filename does not specifically include a path, it will be
-    looked for in the default `pyyc_path` directory.
+    looked for in the default :const:`PYYC_PATH` directory.
 
     :param str cfgname: configuration file name
     :return: configuration object
     :rtype: configparser.ConfigParser
+
+    >>> cfg = read_config()  # doctest: +ELLIPSIS
+    Reading configuration from ...
+    >>> cfg['DEFAULT']['version']
+    'cfg-1.0'
     """
 
     from configparser import ConfigParser
 
-    if os.path.dirname(cfgname):  # cfgname includes a path
+    if os.path.dirname(cfgname):   # cfgname includes a path (e.g. `./path/to/file`)
         fname = cfgname
-    else:                          # use pyyc_path as default
-        fname = pyyc_path.joinpath(cfgname)
+    else:                          # use PYYC_PATH as default
+        fname = PYYC_PATH.joinpath(cfgname)
     print(f"Reading configuration from {fname!s}...")
 
     cfg = ConfigParser()
@@ -89,6 +111,7 @@ def read_config(cfgname="default.cfg"):
 
     return cfg
 
+
 def format_pkg_tree(node, max_depth=2, printout=False, depth=0):
     """
     Format the package architecture.
@@ -96,11 +119,12 @@ def format_pkg_tree(node, max_depth=2, printout=False, depth=0):
     :param module node: name of the top-level module
     :param int max_depth: maximum depth of recursion
     :param bool printout: print out the resulting string
-    :param int depth: used for recursion
+    :param int depth: depth level (used for recursion)
     :return: structure as a list of strings (without newlines)
     :rtype: list
 
-    >>> format_pkg_tree(pyyc, max_depth=1)
+    >>> import pyyc
+    >>> format_pkg_tree(pyyc, max_depth=1)  # doctest: +NORMALIZE_WHITESPACE
     ['pyyc',
      '  pyyc.config',
      '  pyyc.mod',
